stravalib.client.Client
=======================

.. currentmodule:: stravalib.client

.. autoclass:: Client


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~Client.__init__
      ~Client.authorization_url
      ~Client.create_activity
      ~Client.create_subscription
      ~Client.deauthorize
      ~Client.delete_activity
      ~Client.delete_subscription
      ~Client.exchange_code_for_token
      ~Client.explore_segments
      ~Client.get_activities
      ~Client.get_activity
      ~Client.get_activity_comments
      ~Client.get_activity_kudos
      ~Client.get_activity_laps
      ~Client.get_activity_photos
      ~Client.get_activity_streams
      ~Client.get_activity_zones
      ~Client.get_athlete
      ~Client.get_athlete_clubs
      ~Client.get_athlete_koms
      ~Client.get_athlete_starred_segments
      ~Client.get_athlete_stats
      ~Client.get_club
      ~Client.get_club_activities
      ~Client.get_club_members
      ~Client.get_effort_streams
      ~Client.get_friend_activities
      ~Client.get_gear
      ~Client.get_related_activities
      ~Client.get_route
      ~Client.get_route_streams
      ~Client.get_routes
      ~Client.get_segment
      ~Client.get_segment_effort
      ~Client.get_segment_efforts
      ~Client.get_segment_streams
      ~Client.get_starred_segments
      ~Client.handle_subscription_callback
      ~Client.handle_subscription_update
      ~Client.join_club
      ~Client.leave_club
      ~Client.list_subscriptions
      ~Client.refresh_access_token
      ~Client.update_activity
      ~Client.update_athlete
      ~Client.upload_activity





   .. rubric:: Attributes

   .. autosummary::

      ~Client.access_token
